<?php

/*
Pour inclure, rajouter dans le <head> ou au début de votre page :
<?php include('fonctions_utiles.php') ?>
*/


// ********************************************** //
//                                                //
//            Partie sur les sessions             //
//                                                //
// ********************************************** //

// Enregistre les données dans le fichier indiqué
function enregistrer_donnees($donnees, $nom_fichier) {
	file_put_contents($nom_fichier,serialize($donnees));
}


// Renvoie les données contenues dans le fichier indiqué
function lire_donnees($nom_fichier) {
	$donnees_brutes=file_get_contents($nom_fichier);
	return unserialize($donnees_brutes);
}

// Pour commencer une session.
// Une session permet de garder en mémoire des variables
// même lorsqu'on change de page.
function lancer_session() {
	session_start();
}

// Crée ou modifie une variable de session avec la valeur donnée
function enregistrer_valeur_session($nom_variable, $valeur) {
	$_SESSION[$nom_variable] = $valeur;
}

// Renvoie la valeur de la variable de session demandée
// et sinon renvoie le texte vide.
function lire_valeur_session($nom_variable) {
	if (isset($_SESSION[$nom_variable])) {
		return $_SESSION[$nom_variable];
	} else {
	    return "";
	}
}

// Ferme la session et supprime tout ce qui reste en mémoire
function fermer_session() {
	// on efface toutes les valeurs enregistrées
	$_SESSION = array();

	// on nettoie les cookies de session si nécessaire
	if (ini_get("session.use_cookies")) {
		$params = session_get_cookie_params();
		setcookie(session_name(), '', time() - 42000,
			$params["path"], $params["domain"],
			$params["secure"], $params["httponly"]
		);
	}

	// on ferme la session
	session_destroy();
}



// ********************************************** //
//                                                //
//            Partie pour les logins              //
//                                                //
// ********************************************** //


// Vérifie si le login et le mot de passe
// existent et correspondent au contenu du fichier
function tester_connexion($fichier, $login, $mdp) {
	$ok = false;
	if (file_exists($fichier)) {
		$dico_logins = lire_donnees($fichier);
        if ((array_key_exists($login , $dico_logins)) 
            and ($dico_logins[$login] == $mdp)) {
			$ok = true;
		}
	} 
	return $ok;
}

// On essaie d'inscrire le login et le mdp dans le fichier
function tester_inscription($fichier, $login, $mdp) {
	$ok = false;
    if (file_exists($fichier)) {
        // Le fichier existe.
        // On regarde si on a bien un nouveau login.
		$dico_logins = lire_donnees($fichier);
		if (! array_key_exists($login , $dico_logins)) {
			$ok = true;
		}			
    } else {
        // Il n'y a pas de fichier donc
        // on crée un nouveau dictionnaire.
		$ok = true;
		$dico_logins = array();
	}
    if ($ok) {
        // Si tout va bien, on rajoute le login
        // dans le fichier.
		$dico_logins[$login] = $mdp;
		enregistrer_donnees($dico_logins, $fichier);
	}
	return $ok;
}


// ********************************************** //
//                                                //
//              Partie sur les qcm                //
//                                                //
// ********************************************** //


// On regarde si on a une réponse à la question
// donnée dans ce qui a été transmis en POST.
// Sinon on renvoie ""
function obtenir_reponse($nom_question) {
	if (isset($_POST[$nom_question])) {
		return $_POST[$nom_question];
	} else {
		return "";
	}
}

// On regarde si la réponse à la question donnée
// est la bonne réponse.
function est_bonne_reponse($nom_question, $bonne_reponse) {
	return (obtenir_reponse($nom_question) == $bonne_reponse);
}


// Fonction qu'il faudra certainement adapter selon vos besoins
// Cette fonction regarde question par question si la réponse est bonne
// et affiche le nombre de bonne réponses.
// Il faut changer les bonnes réponses en fonction de votre QCM
// et rajouter des lignes si vous avez plus de questions.
function valider_qcm_base() {
	# le bouton de validation doit être :
	# <input type = "submit" name="valider" value = "Texte bouton">
	if (isset($_POST['valider'])) {
		$compteur = 0;
		# les questions sont du genre :
		# <input type="radio" name="question1" value="reponse1">
		# <input type="radio" name="question1" value="reponse2">
		# <input type="radio" name="question1" value="reponse3">
		if (est_bonne_reponse("question1", "reponse3")) {
			$compteur = $compteur + 1;
		}
		if (est_bonne_reponse("question2", "reponse1")) {
			$compteur = $compteur + 1;
		}
		if (est_bonne_reponse("question3", "reponse2")) {
			$compteur = $compteur + 1;
		}
		echo "<p>Vous avez " . $compteur . " bonnes réponses.</p>";
	}
}


/*
    Vous pouvez utiliser les fonctions suivantes en définissant
    un questionnaire de la manière suivante :

$questionnaire = array (
	"question1" => array (
		"reponses" => array (
			"reponse1" => "Un chien",
			"reponse2" => "Un chat",
			"reponse3" => "Un oiseau",
		),
		"enonce" => "Quel est le meilleur animal ?",
		"bonne_reponse" => "reponse1"
	),
	"question2" => array (
		"reponses" => array (
			"reponse1" => "Maths",
			"reponse2" => "NSI",
			"reponse3" => "SES",
		),
		"enonce" => "Quel est la meilleure spécialité ?",
		"bonne_reponse" => "reponse2"
	)
);
 */

// Permet de compter le nombre de bonne réponses
// On peut l'utiliser en ne faisant qu'un dictionnaire des bonnes réponses
function valider_qcm($bonnes_reponses) {
	if (isset($_POST['valider'])) {
		$compteur = 0;
		foreach ($bonnes_reponses as $nom_question => $reponse) {
			if (est_bonne_reponse($nom_question, $reponse)) {
				$compteur = $compteur + 1;
			}
		}
		echo "<p>Vous avez " . $compteur . " bonnes réponses.</p>";
	}
}

// Fait un dictionnaire qui associe à chaque nom de question la bonne réponse
function extraire_bonnes_reponses($questionnaire) {
	$bonnes_reponses = array();
	foreach ($questionnaire as $nom_question => $question) {
		$bonnes_reponses[$nom_question] = $question["bonne_reponse"];
	}
	return $bonnes_reponses;
}

// Affiche le questionnaire en bloquant les questions
// si le questionnaire a été validé.
// Les réponses sont mises en couleur en indiquant si c'est
// la bonne ou non.
function afficher_qcm($questionnaire, $destination="#") {
	echo '<form action = "'.$destination.'" method = "post">'.PHP_EOL;
	$style_base = "";
	$style_rouge = " style='color:red;' ";
	$style_vert = " style='color:green;' ";
	foreach ($questionnaire as $nom_question => $question) {
		echo "<label>".$question["enonce"]."</label><br>".PHP_EOL;
		$defaut = array_keys($question["reponses"])[0];
		$desactiver = false;
        if (obtenir_reponse($nom_question) != "") {
            // On a déjà une réponse alors on bloque la question
			$defaut = obtenir_reponse($nom_question);
			$desactiver = true;
		}
		foreach ($question["reponses"] as $reponse => $rep) {
			$style = $style_base;
			echo '<input type="radio" name="'.$nom_question.'" ';
			echo 'value="'.$reponse.'"';
			if ($reponse == $defaut) {
				echo " checked ";
			}
            if ($desactiver) {
                // On désactive le bouton
                echo " disabled ";
                // On met la couleur appropriée
				if ($reponse == $question["bonne_reponse"]) {
					$style = $style_vert;
				} else {
					$style = $style_rouge;
				}
			}
			echo ">".PHP_EOL;
			echo "<label".$style.">".$rep."</label><br>".PHP_EOL;
		}
	}
	echo '<input type = "submit" name="valider" value = "Valider">'.PHP_EOL;
	echo '</form>'.PHP_EOL;
}
?>
